powered by
A function that generates random strings
random_strings(N, string_size = 50L, charset = "abcdefghijklmnopqrstuvwxyz", vector_mode = "stringfish")
A character vector of the random strings
The number of strings to generate
Either a single non-negative integer applied to every output string, or a non-negative integer vector of length `N`.
The characters used to generate the random strings (default: abcdefghijklmnopqrstuvwxyz)
The type of character vector to generate (either stringfish or normal, default: stringfish)
A convenience function for generating test strings.
set.seed(1) x <- random_strings(1e6, 80L, "ACGT", vector_mode = "stringfish") y <- random_strings(4, c(1L, 2L, 4L, 8L), "ACGT")
Run the code above in your browser using DataLab