powered by
A function for detecting a pattern at the end of a string
sf_ends(subject, pattern, ...)
A logical vector true if there is a match, false if no match, NA is the subject was NA
A character vector
A string to look for at the start
Parameters passed to sf_grepl
endsWith, sf_starts
x <- c("alpha", "beta", "gamma", "delta", "epsilon") sf_ends(x, "a")
Run the code above in your browser using DataLab