powered by
A function that reads a file line by line
sf_readLines(file, encoding = "UTF-8")
A stringfish vector of the lines in a file
The file name
The encoding to use (Default: UTF-8)
A function for reading in text data using `std::ifstream`.
readLines
file <- tempfile() sf_writeLines(letters, file) sf_readLines(file)
Run the code above in your browser using DataLab