Learn R Programming

stringfish (version 0.19.2)

slice_store_create_with_size: slice_store_create_with_size

Description

Creates a new empty slice-store-backed stringfish vector with a fixed initial slice size

Usage

slice_store_create_with_size(len, initial_slice_size)

Value

A new slice-store-backed stringfish vector

Arguments

len

length of the new vector

initial_slice_size

Initial size of the first underlying `slice_store` slice.

Details

This function creates a new stringfish vector backed by `slice_store`, and uses `initial_slice_size` for the first slice allocation instead of the default heuristic. If you want to fill the vector from character data, use `convert_to_slice_store`.

Examples

Run this code
x <- slice_store_create_with_size(4, 256)

Run the code above in your browser using DataLab