Creates a new empty slice-store-backed stringfish vector
Usage
slice_store_create(len)
Value
A new slice-store-backed stringfish vector
Arguments
len
length of the new vector
Details
This function creates a new stringfish vector backed by `slice_store`,
which stores string bytes in append-only slices plus per-element records.
If you want to fill the vector from character data, use `convert_to_slice_store`.