Initial size of the first underlying `slice_store` slice.
Details
This function creates a new stringfish vector backed by `slice_store`,
and uses `initial_slice_size` for the first slice allocation instead of the default heuristic.
If you want to fill the vector from character data, use `convert_to_slice_store`.